@@ -11,7 +11,7 @@ import rpy2.robjects.methods
 import rpy2.robjects as robjects
 import rpy2.robjects.conversion as conversion
 from rpy2.rlike.container import OrdDict
-from rpy2.robjects.packages import importr
+from rpy2.robjects.packages import importr, WeakPackage
 
 NULL = robjects.NULL
 
@@ -19,6 +19,15 @@ NULL = robjects.NULL
 
 grid = importr('grid')
 
+grid = WeakPackage(grid._env,
+                   grid.__rname__,
+                   translation=grid._translation,
+                   exported_names=grid._exported_names,
+                   on_conflict="warn",
+                   version=grid.__version__,
+                   symbol_r2python=grid._symbol_r2python,
+                   symbol_check_after=grid._symbol_check_after)
+
 grid_env = robjects.baseenv['as.environment']('package:grid')
 
 
@@ -41,7 +50,7 @@ class Unit(robjects.RObject):
         od = OrdDict()
         for item in args:
             od[None] = conversion.py2ro(item)
-        for k, v in kwargs.iteritems():
+        for k, v in kwargs.items():
             od[k] = conversion.py2ro(v)
         res = self._constructor.rcall(tuple(od.items()), robjects.globalenv)
         self.__sexp__ = res.__sexp__
@@ -63,7 +72,7 @@ class Gpar(robjects.RObject):
         od = OrdDict()
         for item in args:
             od[None] = conversion.py2ro(item)
-        for k, v in kwargs.iteritems():
+        for k, v in kwargs.items():
             od[k] = conversion.py2ro(v)
         res = self._constructor.rcall(tuple(od.items()), robjects.globalenv)
         self.__sexp__ = res.__sexp__
@@ -88,7 +97,7 @@ class Grob(robjects.RObject):
         od = OrdDict()
         for item in args:
             od[None] = conversion.py2ro(item)
-        for k, v in kwargs.iteritems():
+        for k, v in kwargs.items():
             od[k] = conversion.py2ro(v)
         res = self._constructor.rcall(tuple(od.items()), robjects.globalenv)
         self.__sexp__ = res.__sexp__
@@ -228,12 +237,11 @@ class Viewport(robjects.RObject):
     def viewport(cls, **kwargs):
         """ Constructor: create a Viewport """
         res = cls._viewport(**kwargs)
+        res = cls(res)
         return res
 
 viewport = Viewport.viewport
 
-
-
 _grid_dict = {
     'grob': Grob,
     'gTree': GTree,
@@ -242,11 +250,13 @@ _grid_dict = {
     'viewport': Viewport
 }
 
-original_conversion = conversion.ri2py
+original_py2ri = None
+original_ri2ro = None
+original_py2ro = None
 
-def grid_conversion(robj):
+def grid_ri2ro(robj):
 
-    pyobj = original_conversion(robj)
+    pyobj = original_ri2ro(robj)
 
     if not isinstance(pyobj, robjects.RS4):
         rcls = pyobj.rclass
@@ -255,9 +265,35 @@ def grid_conversion(robj):
         try:
             cls = _grid_dict[rcls[0]]
             pyobj = cls(pyobj)
-        except KeyError, ke:
+        except KeyError as ke:
             pass
 
     return pyobj
 
-conversion.ri2py = grid_conversion
+def activate():
+    global original_py2ri, original_ri2ro, original_py2ro
+
+    # If module is already activated, there is nothing to do
+    if original_py2ri: 
+        return
+
+    original_py2ri = conversion.py2ri
+    original_ri2ro = conversion.ri2ro
+    original_py2ro = conversion.py2ro
+
+    #conversion.py2ri = numpy2ri
+    conversion.ri2ro = grid_ri2ro
+    #conversion.py2ro = numpy2ro
+
+def deactivate():
+    global original_py2ri, original_ri2ro, original_py2ro
+
+    # If module has never been activated or already deactivated,
+    # there is nothing to do
+    if not original_py2ri:
+        return
+
+    conversion.py2ri = original_py2ri
+    conversion.ri2ro = original_ri2ro
+    conversion.py2ro = original_py2ro
+    original_py2ri = original_ri2ro = original_py2ro = None
